django_premailer package — django-premailer 0.1.0 documentation

# django_premailer package

## Subpackages

- django_premailer.templatetags package
  - Submodules
  - django_premailer.templatetags.premailer module
  - Module contents
- django_premailer.tests package
  - Subpackages
    - django_premailer.tests.testapp package
      - Submodules
      - django_premailer.tests.testapp.settings module
      - django_premailer.tests.testapp.urls module
      - django_premailer.tests.testapp.views module
      - Module contents
  - Submodules
  - django_premailer.tests.test_templatetags module
  - Module contents

## Submodules

## django_premailer.models module

## Module contents

Django template tag that turns CSS blocks into style attributes using premailer.

class `django_premailer.` `version_info_t`(major, minor, micro, releaselevel, serial)

  Bases: `tuple`

  `major`

    Alias for field number 0

  `micro`

    Alias for field number 2

  `minor`

    Alias for field number 1

  `releaselevel`

    Alias for field number 3

  `serial`

    Alias for field number 4